@@ -13,6 +13,8 @@ import sys
 
 
 class ExampleRunner(object):
+    flavors = set()
+
     def __init__(self, verbosity, encoding, **unused):
         self.verbosity = verbosity
         self.encoding = encoding
@@ -192,6 +194,7 @@ class PexpectMixin(object):
 
         self._drop_output()  # there shouldn't be any output yet but...
         self._cmd = cmd
+        clog().info("Spawn command line: %s", cmd)
         try:
             self._interpreter = pexpect.spawn(
                 cmd,
@@ -269,9 +272,33 @@ class PexpectMixin(object):
     @profile
     def _shutdown_interpreter(self):
         self._interpreter.sendeof()
-        self._interpreter.close()
+        try:
+            self._interpreter.close()
+        except Exception as ex:
+            clog().debug(
+                "Call to close() on interpreter failed (may happen): %s.",
+                str(ex)
+            )
+
         time.sleep(0.001)
-        self._interpreter.terminate(force=True)
+        try:
+            self._interpreter.terminate(force=True)
+        except Exception as ex:
+            clog().debug(
+                "Call to terminate() on interpreter failed (may happen): %s.",
+                str(ex)
+            )
+
+        time.sleep(0.001)
+        if self._interpreter.isalive():
+            who = tohuman(
+                self.language
+                if hasattr(self, 'language') and self.language else self
+            )
+            clog().warn(
+                "Incomplete '%s' Runner shutdown: too slow and it is still running.",
+                who
+            )
 
     @profile
     def _exec_and_wait(self, source, options, *, from_example=None, **kargs):
@@ -545,7 +572,18 @@ class PexpectMixin(object):
         # get each line in the Terminal's display and ignore each one that
         # starts with our cookie: those are the "echo" lines that
         # *we* sent to the interpreter and they are not part of *its* output.
-        return (line for line in lines if not line.startswith(cookie))
+        filtered_lines = (
+            line for line in lines if not line.startswith(cookie)
+        )
+
+        # a prompt may be at the end of the last line if the interpreter printed
+        # something without adding a newline to separate it from the prompt.
+        # for simplicity I will remove any prompt that it may be at
+        # the end of all the lines:
+        return (
+            line[:-len(cookie)] if line.endswith(cookie) else line
+            for line in filtered_lines
+        )
 
     def _set_cooked_mode(self, state):  # pragma: no cover
         # code borrowed from ptyprocess/ptyprocess.py, _setecho, and
